@@ -534,6 +534,14 @@ int xdo_focus_window(const xdo_t *xdo, Window wid);
  */
 int xdo_raise_window(const xdo_t *xdo, Window wid);
 
+/**
+ * Lower a window to the bottom of the window stack. This is also sometimes
+ * termed as sending the window backward.
+ *
+ * @param wid The window to lower.
+ */
+int xdo_lower_window(const xdo_t *xdo, Window wid);
+
 /**
  * Get the window currently having focus.
  *
@@ -618,6 +626,13 @@ int xdo_minimize_window(const xdo_t *xdo, Window wid);
 #define _NET_WM_STATE_ADD           1    /* add/set property */
 #define _NET_WM_STATE_TOGGLE        2    /* toggle property  */
 
+/**
+ * Get window classname
+ * @param window the window
+ * @param class_ret Pointer to the window classname WM_CLASS
+ */
+int xdo_get_window_classname(const xdo_t *xdo, Window window, unsigned char **class_ret);
+
 /**
  * Change window state
  * @param action the _NET_WM_STATE action
@@ -921,11 +936,6 @@ int xdo_get_viewport_dimensions(xdo_t *xdo, unsigned int *width,
                                 unsigned int *height, int screen);
 
 
-/**
- * Get the classname of a given Window.
- */
-int xdo_get_window_classname(const xdo_t *xdo, Window window, unsigned char **name_ret);
-
 #ifdef __cplusplus
 } /* extern "C" */
 #endif
